# encoding:utf-8
from setuptools import setup

setup(
    name='alfred-workflow-flyer',
    version='0.0.1',
    author='Pushy',
    author_email='1437876073@qq.com',
    url='',
    description=u'A simple scaffold of alfred workflow',
    packages=['workflow_flyer'],
    install_requires=['Alfred-Workflow']
)
